@@ -1,40 +1,35 @@
 package Class::PObject::Driver::DBI;
 
-# $Id: DBI.pm,v 1.7 2003/08/27 00:23:37 sherzodr Exp $
+# $Id: DBI.pm,v 1.10 2003/09/09 00:11:54 sherzodr Exp $
 
 use strict;
+#use diagnostics;
 use Carp;
 use Log::Agent;
 use Class::PObject::Driver;
-use Data::Dumper;
 use vars ('$VERSION', '@ISA');
 
 @ISA = ('Class::PObject::Driver');
 
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 
 sub _prepare_where_clause {
     my ($self, $terms) = @_;
 
     $terms ||= {};
-
     unless ( ref $terms ) {
         die join ', ', caller(0)
     }
-
     # if no terms present, just return an empty string
     unless ( keys %$terms ) {
         return ("", ());
     }
-
     my ($sql, @where, @bind_params);
-
     while ( my ($k, $v) = each %$terms ) {
         push @where, "$k=?";
         push @bind_params, $v
     }
-
     $sql = "WHERE " . join (" AND ", @where);
     return ($sql, \@bind_params)
 }
@@ -42,13 +37,12 @@ sub _prepare_where_clause {
 
 
 sub _prepare_select {
-    my ($self, $table_name, $terms, $args) = @_;
-
-    my ($sql, @where, @bind_params);
+    my ($self, $table_name, $terms, $args, $cols) = @_;
 
+    my ($sql, @where, @bind_params, $selected_cols);
     my ($where_clause, $bind_params) = $self->_prepare_where_clause($terms);
-    $sql = "SELECT * FROM $table_name " . $where_clause;
-
+    $selected_cols = $cols ? join (", ", @$cols) : "*";
+    $sql = sprintf("SELECT %s FROM %s %s", $selected_cols, $table_name, $where_clause);
     if ( defined $args ) {
         $args->{limit}      ||= 1000;
         $args->{offset}     ||= 0;
@@ -169,7 +163,7 @@ sub load_ids {
 
     my $dbh   = $self->dbh($object_name, $props)              or return;
     my $table = $self->_tablename($object_name, $props, $dbh) or return;
-    my ($sql, $bind_params)   = $self->_prepare_select($table, $terms, $args);
+    my ($sql, $bind_params)   = $self->_prepare_select($table, $terms, $args, ['id']);
     
     
     my $sth   = $dbh->prepare( $sql );
@@ -207,7 +201,7 @@ sub remove {
 
     my $dbh                 = $self->dbh($object_name, $props)              or return;
     my $table               = $self->_tablename($object_name, $props, $dbh) or return;
-    my ($sql, $bind_params) = $self->_prepare_delete($table);
+    my ($sql, $bind_params) = $self->_prepare_delete($table, {id=>$id});
 
     my $sth                 = $dbh->prepare( $sql );
     unless ( $sth->execute($id) ) {
@@ -312,7 +306,6 @@ sub _unlock {
 
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
@@ -326,13 +319,11 @@ Class::PObject::Driver::DBI - Base class for all DBI-related drivers
 
     sub save {
         my ($self, $pobject_name, \%properties, \%columns) = @_;
-
         ...
     }
 
     sub dbh {
         my ($self, $pobject_name, \%properties) = @_;
-
         ...
     }
 
@@ -344,12 +335,12 @@ Class::PObject::Driver::DBI - Base class for all DBI-related drivers
 
 =head1 STOP!
 
-If you just want to be able to use Class::PObject> this manual is not for you.
+If you just want to be able to use L<Class::PObject|Class::PObject> this manual is not for you.
 This is for those willing to write I<pobject> drivers to support other database
 systems and storage devices.
 
 If you just want to be able to use Class::PObject, you should refer to its
-L<online manual|Class::PObject> instead.
+L<manual|Class::PObject> instead.
 
 =head1 DESCRIPTION
 
@@ -358,7 +349,7 @@ and overrides the methods provided in Class::PObject::Driver with those more rel
 to RDBMS engines.
 
 It uses ANSI-SQL syntax, so most of the base methods should perform as expected for most
-RDBMS that supports ANSI-SQL syntax.
+RDBMS that support ANSI-SQL syntax.
 
 For those that don't, you can override necessary methods from within your driver class.
 This manual will not discuss the list of base methods, for they all are documented in
@@ -379,7 +370,8 @@ For details on C<save()> method, refer to L<Class::PObject::Driver|Class::PObjec
 =item *
 
 C<dbh($self, $pobject_name, \%properties)> - will be called by other base methods whenever
-a database handle is needed. It receives all the standard arguments (L<Class::PObject::Driver>)
+a database handle is needed. It receives all the standard arguments 
+(see L<Class::PObject::Driver|Class::PObject::Driver>)
 
 If your project consists of several pobjects, which is very common, you may want to C<stash()>
 the created database handle to ensure Class::PObject will be able to re-use the same object
@@ -419,9 +411,8 @@ Example:
 
 =item *
 
-C<_prepare_select($self, $table_name, \%terms, \%args)> - prepares a I<SELECT> SQL statement,
-given $table_name, \%terms and \%args. The last two arguments are the same as the ones passed
-to C<load()> pobject method.
+C<_prepare_select($self, $table_name, \%terms, \%args, \@cols)> - prepares a I<SELECT> SQL statement,
+given $table_name, \%terms and \%args and \@cols.
 
 Example:
 
@@ -474,15 +465,8 @@ it into SQL statements.
 
 L<Class::PObject::Driver>
 
-=head1 AUTHOR
-
-Sherzod B. Ruzmetov, E<lt>sherzodr@cpan.orgE<gt>, http://author.handalak.com/
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Sherzod B. Ruzmetov.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
 
 =cut
