@@ -1,6 +1,6 @@
 package Class::PObject::Driver::db_file;
 
-# $Id: db_file.pm,v 1.5 2003/11/07 04:43:14 sherzodr Exp $
+# $Id: db_file.pm,v 1.3 2003/09/09 00:11:54 sherzodr Exp $
 
 use strict;
 #use diagnostics;
@@ -30,23 +30,6 @@ sub dbh {
 
 
 
-sub drop_datasource {
-    my ($self, $object_name, $props) = @_;
-
-    my (undef, $dbh, $unlock) = $self->dbh($object_name, $props, 'w') or return;
-    my $filename = $self->_filename($object_name, $props);
-    unless ( unlink $filename ) {
-        $self->errstr( "couldn't unlink '$filename': $!" );
-        return undef
-    }
-    $unlock->();
-    return 1
-}
-
-
-
-
-
 sub _filename {
     my ($self, $object_name, $props) = @_;
 
