@@ -1,8 +1,9 @@
 package Class::PObject::Iterator;
 
-# $Id: Iterator.pm,v 1.4 2003/08/27 17:39:47 sherzodr Exp $
+# $Id: Iterator.pm,v 1.7 2003/09/09 00:11:53 sherzodr Exp $
 
 use strict;
+#use diagnostics;
 use Carp 'croak';
 use vars ('$VERSION');
 
@@ -15,7 +16,7 @@ sub new {
     my $self = {
         pobject     => $_[0],
         data_set    => $_[1],
-        next_pointer=> 0,
+        next_ptr=> 0,
         last_ptr    =>  scalar(@{$_[1]})-1
     };
 
@@ -25,7 +26,6 @@ sub new {
 sub DESTROY { 
     my $self = shift;
 
-    $self->finish()
 }
 
 sub next {
@@ -42,7 +42,6 @@ sub next {
 
 sub size {
     my $self = shift;
-
     return $self->{last_ptr} - $self->{next_ptr} + 1
 }
 
@@ -70,8 +69,7 @@ sub push {
 sub finish {
     my $self = shift;
 
-    $self->{data_set} = undef;
-    $self->{pobject}  = undef;
+    $self->{data_set} = []
 }
 
 
@@ -84,11 +82,8 @@ sub dump {
     return $d->Dump
 }
 
-
-
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
@@ -156,20 +151,12 @@ and want to start from clean data set:
 
 =back
 
-
 =head1 SEE ALSO
 
 L<Class::PObject>
 
-=head1 AUTHOR
-
-Sherzod B. Ruzmetov, E<lt>sherzodr@cpan.orgE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Sherzod B. Ruzmetov.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
 
 =cut
