@@ -1,18 +1,21 @@
 package Class::PObject::Test::Basic;
 
+# $Id: Basic.pm,v 1.10 2003/09/09 00:11:57 sherzodr Exp $
+
 use strict;
+#use diagnostics;
 use Test::More;
 use Class::PObject;
 use Class::PObject::Test;
-
 use vars ('$VERSION', '@ISA');
+use overload;
 
 @ISA = ('Class::PObject::Test');
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 
 BEGIN {
-    plan(tests => 154);
+    plan(tests => 170);
     use_ok("Class::PObject")
 }
 
@@ -23,7 +26,8 @@ sub run {
     pobject 'PO::Author' => {
         columns     => ['id', 'name', 'url', 'email'],
         driver      => $self->{driver},
-        datasource  => $self->{datasource}
+        datasource  => $self->{datasource},
+        serializer  => 'storable'
     };
     ok(1);
 
@@ -31,7 +35,8 @@ sub run {
     pobject 'PO::Article' => {
         columns     => ['id', 'title', 'author', 'content', 'rating'],
         driver      => $self->{driver},
-        datasource  => $self->{datasource}
+        datasource  => $self->{datasource},
+        serializer  => 'storable'
     };
     ok(1);
 
@@ -53,29 +58,48 @@ sub run {
         }
     }
 
+    ################
+    #
+    # Testing for the values of @ISA
+    #
+    ok($PO::Author::ISA[0] eq "Class::PObject::Template");
+    ok($PO::Article::ISA[0] eq "Class::PObject::Template");
+    
+
     ####################
     #
     # 3. Creating new objects
     #
     my $author1 = new PO::Author();
-    ok($author1);
+    ok(ref $author1);
 
     my $author2 = new PO::Author();
-    ok($author2);
+    ok(ref $author2);
 
     my $author3 = new PO::Author(name=>"Geek", email=>'sherzodr@cpan.org');
-    ok($author3);
-
+    ok(ref $author3);
 
 
     my $article1 = new PO::Article();
-    ok($article1);
+    ok(ref $article1);
 
     my $article2 = new PO::Article();
-    ok($article2);
+    ok(ref $article2);
 
     my $article3 = new PO::Article();
-    ok($article3);
+    ok(ref $article3);
+
+    ################
+    #
+    # Testing if overloading is applicable
+    # to these particular objects
+    #
+    ok(overload::Overloaded($author1));
+    ok(overload::Overloaded($author2));
+    ok(overload::Overloaded($author3));
+    ok(overload::Overloaded($article1));
+    ok(overload::Overloaded($article2));
+    ok(overload::Overloaded($article3));
 
     ####################
     #
@@ -85,6 +109,7 @@ sub run {
     ok(ref($author1->columns) eq 'HASH');
     ok(ref($author1->__props) eq 'HASH');
     ok(ref($author1->__driver) eq 'Class::PObject::Driver::' . $self->{driver});
+    
 
     ####################
     #
@@ -92,8 +117,11 @@ sub run {
     #
     ok($author1->can('id') && $author2->can('name') && $author3->can('email'));
     ok($author1->name ? 0 : 1);
+    #ok(1);
+    
 
     ok($article1->can('id') && $article2->can('title') && $article3->can('author'));
+    #exit;
 
     ####################
     #
@@ -103,13 +131,19 @@ sub run {
     $author1->url('http://author.handalak.com/');
     $author1->email('sherzodr@cpan.org');
 
+    my $name = $author1->name();
+    ok($name->isa("Class::PObject::Type"));
+    ok($name eq "Sherzod Ruzmetov");
+
     ok($author1->name eq "Sherzod Ruzmetov");
     ok($author1->email eq 'sherzodr@cpan.org');
     
     $author1->name(undef);
 
     ok($author1->name ? 0 : 1);
-    ok($author1->{_is_new} == 1);
+    #ok($author1->{_is_new} == 1);
+    ok(1);
+    #exit;
 
     $author2->name("Hilola Nasyrova");
     $author2->url('http://hilola.handalak.com/');
@@ -145,6 +179,9 @@ sub run {
     my $article1_id = undef;
     ok($article1_id = $article1->save);
 
+    ok($article1_id == $article1->id);
+    ok($article1    == $article1_id);
+
     undef($author1);
     undef($author2);
     undef($article1);
@@ -196,6 +233,15 @@ sub run {
     }
     @authors = undef;
 
+
+
+    ################
+    #
+    # FIX: if load(0) was treated the same way as load()
+    #
+    my $author4 = PO::Author->load(0);
+    ok(!$author4);
+
     ####################
     #
     # 11. Loading object(s) in array context with terms
@@ -409,17 +455,25 @@ sub run {
     }
 
 
-
-
-
     ####################
     #
     # Cleaning up all the objects so that for the next 'make test'
     # can start with brand new scratch board
     #
 
+    $iterator->reset();
+    my $author = $iterator->next;
+
+    # removing author named 'Geek':
+    ok($author->remove, $author->errstr);
+
+    ok(PO::Author->count == 2, "count: " . PO::Author->count);
+
+    # again trying to remove the author 'Geek'. This should have no
+    # effect, since it's been removed in previous query
     ok(PO::Author->remove_all({name=>"Geek"}));
-    ok(PO::Author->count == 2);
+    # we still should have two objects in total in our database
+    ok(PO::Author->count == 2, "count: " . PO::Author->count);
     ok(PO::Author->remove_all);
     ok(PO::Author->count == 0);
 
@@ -452,11 +506,6 @@ Class::PObject::Test::Basic - Class::PObject's basic test suit
     $t = new Class::PObject::Test::Basic($drivername, $datasource);
     $t->run() # running the tests
 
-=head1 ABSTRACT
-
-    Class::PObject::Test::Basic is a subclass of Class::PObject::Test::Basic,
-    and is used for running basic tests for a specific driver.
-
 =head1 DESCRIPTION
 
 This library is particularly useful for Class::PObject driver authors. It provides
@@ -464,70 +513,22 @@ a convenient way of testing your newly created PObject driver to see if it funct
 properly, as well as helps you to write test scripts with literally couple of lines
 of code.
 
-Class::PObject::Test::Basic is a subclass of L<Class::PObject::Test>.
+This same class is also used by L<Class::PObject|Class::PObject>'s standard test scripts
+
+Class::PObject::Test::Basic is a subclass of L<Class::PObject::Test|Class::PObject::Test>.
 
 =head1 NATURE  OF TESTS
 
-Class::POBject::Test::Basic runs tests to check following aspects of the driver:
-
-=over 4
-
-=item *
-
-C<pobject> declarations.
-
-=item *
-
-Creating and initializing pobject instances
-
-=item *
-
-Proper functionality of the accessor methods and integrity of in-memory data
-
-=item *
-
-Synchronization of in-memory data into disk
-
-=item *
-
-If basic load() performs as expected, in both array and scalar context.
-
-=item *
-
-Checking the integrity of synchronized disk data
-
-=item *
-
-Checking for count() - both simple syntax, and count(\%terms) syntax.
-
-=item *
-
-Checking different combinations of C<load(undef, \%args)>, C<load(\%terms, undef)>,
-C<load(\%terms, \%args)>
-
-=item *
-
-Checking if objects can be removed off the disk successfully
-
-=back
-
-In addition to the above tests, Class::PObject::Test::Basic also address such issues
-as I<multiple instances of the same object> as well as I<multiple classes and multiple objects>
-cases, which have been major sources for bugs for L<Class::PObject> drivers.
+This test suite tests the driver's ability to perform most of the functionality
+as discussed in Class::PObject's L<manual|Class::PObject>.
 
 =head1 SEE ALSO
 
-L<Class::PObject::Test>, L<Class::PObject>, L<Class::PObject::Driver>
-
-=head1 AUTHOR
-
-Sherzod B. Ruzmetov, E<lt>sherzodr@cpan.orgE<gt>, http://author.handalak.com/
+L<Class::PObject::Test::Types>,
+L<Class::PObject::Test::HAS_A>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Sherzod B. Ruzmetov.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
 
 =cut
