@@ -1,14 +1,15 @@
 package Class::PObject::Test::HAS_A;
 
-# $Id: HAS_A.pm,v 1.5 2003/11/06 01:21:10 sherzodr Exp $
+# $Id: HAS_A.pm,v 1.3 2003/09/09 00:11:57 sherzodr Exp $
 
 use strict;
 #use diagnostics;
 use Test::More;
+use Data::Dumper;
 use vars ('$VERSION', '@ISA');
 
 BEGIN {
-    plan(tests => 37);
+    plan(tests => 35);
     use_ok("Class::PObject");
     use_ok("Class::PObject::Test")
 }
@@ -126,8 +127,8 @@ sub run {
 
     #print $article->dump;
 
-    ok($article->title eq "Class::PObject now supports type-mapping");
-    ok($article->author->name eq "Sherzod Ruzmetov",    ''.$article->author->name);
+    ok($article->title eq "Class::PObject now supports type-mapping", $article->title);
+    ok($article->author->name eq "Sherzod Ruzmetov",    $article->author->name);
     ok(ref($article->author) eq "PO::Author",                ref($article->author));
 
     ok($article->save == $article_id, $article->errstr);
@@ -141,8 +142,8 @@ sub run {
 
     ok($author = $article->author);
     #print $article->dump;
-    ok($article->title eq "Class::PObject now supports type-mapping");
-    ok($author->name eq "Sherzod Ruzmetov",    ''.$article->author->name);
+    ok($article->title eq "Class::PObject now supports type-mapping", $article->title);
+    ok($author->name eq "Sherzod Ruzmetov",    $article->author->name);
     ok(ref($author) eq "PO::Author",                ref($article->author));
 
     #print Dumper($article);
@@ -164,9 +165,6 @@ sub run {
     ok(PO::Article->count({author=>$author}) == 1);
     ok(PO::Article->remove_all);
     ok(PO::Article->count({author=>$author}) == 0);
-
-    ok(PO::Article->drop_datasource);
-    ok(PO::Author->drop_datasource);
 }
 
 1;
